#!/usr/bin/env python
# coding: utf-8

from setuptools import setup

setup(
    name='mymaterial',
    version='0.0.1',
    author='zhouzi',
    author_email='3222676446@qq.com',
    url='https://github.com/zhijiuxing-alt/mkdocs-material.git',
    description='用于测试的',
    install_requires=[],
    entry_points={
        'console_scripts': [
           
        ]
    }
)
